==> zio-aws-macie2_3-5.17.124.3-sources.jar: zio/aws/macie2/model/DeleteCustomDataIdentifierRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteCustomDataIdentifierRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest = {
    import DeleteCustomDataIdentifierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.ReadOnly =
    zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.wrap(buildAwsValue())
}
object DeleteCustomDataIdentifierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DeleteCustomDataIdentifierRequest =
      zio.aws.macie2.model.DeleteCustomDataIdentifierRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
  ) extends zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.ReadOnly {
    override val id: __string =
      zio.aws.macie2.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
  ): zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-macie2_3-7.28.26.1-sources.jar: zio/aws/macie2/model/DeleteCustomDataIdentifierRequest.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteCustomDataIdentifierRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest = {
    import DeleteCustomDataIdentifierRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.ReadOnly =
    zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.wrap(buildAwsValue())
}
object DeleteCustomDataIdentifierRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.DeleteCustomDataIdentifierRequest =
      zio.aws.macie2.model.DeleteCustomDataIdentifierRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
  ) extends zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.DeleteCustomDataIdentifierRequest
  ): zio.aws.macie2.model.DeleteCustomDataIdentifierRequest.ReadOnly =
    new Wrapper(impl)
}
